@@ -7,15 +7,24 @@ from logging import Logger
 from logging import Formatter
 from logging import FileHandler
 from logging import StreamHandler
-from logging import (NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL)
+from logging import (NOTSET,
+                     DEBUG,
+                     INFO,
+                     WARNING,
+                     ERROR,
+                     CRITICAL)
 
 from .. util.filesystem import parse_path
 from .. util.filesystem import standardize_dir
 from .. util.text import object_name
 from .. util.text import vengeance_message
 
+from .. conditional import is_tty_console
+
 
 class log_cls(Logger):
+    banner_character   = '*'
+    banner_width       = None
 
     def __init__(self, path_or_name='',
                        level='DEBUG',
@@ -34,22 +43,25 @@ class log_cls(Logger):
             sys.excepthook is automatically set to self.exception_handler if
             exception_callback is a valid function
         """
+
         if (exception_callback is not None) and not callable(exception_callback):
             raise TypeError('exception_callback must be callable')
 
-        filedir, logname, extn = parse_path(path_or_name, explicit_cwd=False)
+        (filedir,
+         logname,
+         extension) = parse_path(path_or_name, explicit_cwd=False)
         if isinstance(level, str):
             level = level.upper().strip()
 
         super().__init__(logname, level)
 
-        self.path      = self.__set_path(filedir, logname, extn)
+        self.path      = self.__set_path(filedir, logname, extension)
         self.formatter = Formatter(log_format)
 
         self.exception_callback = exception_callback
         self.exception_message  = ''
-        self.banner_character   = '*'
-        self.banner_width       = None
+        # self.banner_character   = '*'
+        # self.banner_width       = None
 
         self._add_stream_handler(sys.stdout)
         self._add_file_handler(self.path)
@@ -102,9 +114,8 @@ class log_cls(Logger):
             self.removeHandler(h)
 
     def _add_stream_handler(self, stream):
-        is_terminal = stream.isatty()
-
-        if is_terminal:
+        # TTY console doesn't support ascii escapes
+        if is_tty_console:
             h = StreamHandler(stream)
         else:
             h = colored_streamhandler_cls(stream)
@@ -136,7 +147,7 @@ class log_cls(Logger):
             self.exception_message = self.__formatted_exception_message(e_type, e_msg, e_traceback)
         except Exception:
             self.exception_message = 'error occurred in log_cls.__formatted_exception_message()'
-            vengeance_message(self.exception_message)
+            print(vengeance_message(self.exception_message))
 
         self.error(self.exception_message, exc_info=(e_type, e_msg, e_traceback))
 
@@ -169,10 +180,6 @@ class log_cls(Logger):
                                 *[len(line) for line in str(filename).split('\n')]]) + 10
             banner_width = max(banner_width, 90)
 
-        # banner_top    = '{}^{}'.format(self.banner_character, banner_width)
-        # banner_top    = '{:{}}'.format('  ' + repr(self) + '  ', banner_top)
-        # banner_bottom = banner_char * len(banner_top)
-
         banner_top    = self.banner_character * banner_width
         banner_bottom = self.banner_character * banner_width
 
@@ -198,19 +205,19 @@ class log_cls(Logger):
         return exception_message
 
     @staticmethod
-    def __set_path(filedir, logname, extn):
-        if extn == '.py':
-            extn = ''
+    def __set_path(filedir, logname, extension):
+        if extension == '.py':
+            extension = ''
 
-        if not (filedir or extn):
+        if not (filedir or extension):
             return ''
 
         filedir = standardize_dir(filedir, explicit_cwd=True)
         if not os.path.exists(filedir):
             os.makedirs(filedir)
 
-        extn = extn or '.log'
-        path = filedir + logname + extn
+        extension = extension or '.log'
+        path = filedir + logname + extension
 
         return path
 
@@ -218,20 +225,20 @@ class log_cls(Logger):
         return 'vengeance log: {}'.format(self.name)
 
 
+# noinspection DuplicatedCode
 class colored_streamhandler_cls(StreamHandler):
 
     # https://en.wikipedia.org/wiki/ANSI_escape_code
     level_colors  = {NOTSET:   'grey',
                      DEBUG:    'grey',
                      INFO:     'white',
-                     WARNING:  'bright_yellow',
+                     WARNING:  'bright yellow',
                      ERROR:    'red',
-                     CRITICAL: 'bright_magenta'}
-    ascii_escapes = {'end':            '\x1b[0m',       # misc
-                     'bold':           '\x1b[1m',
+                     CRITICAL: 'bright magenta'}
+
+    ascii_escapes = {'bold':           '\x1b[1m',       # effects
                      'italic':         '\x1b[3m',
                      'underline':      '\x1b[4m',
-
                      'grey':           '\x1b[29m',      # colors
                      'white':          '\x1b[30m',
                      'red':            '\x1b[31m',
@@ -241,9 +248,13 @@ class colored_streamhandler_cls(StreamHandler):
                      'magenta':        '\x1b[35m',
                      'green':          '\x1b[36m',
                      'bronze':         '\x1b[37m',
-                     'bright_red':     '\x1b[91m',
-                     'bright_yellow':  '\x1b[93m',
-                     'bright_magenta': '\x1b[95m'}
+                     'bright red':     '\x1b[91m',
+                     'bright yellow':  '\x1b[93m',
+                     'bright magenta': '\x1b[95m',
+                     'bright cyan':    '\x1b[96m',
+                     'end':            '\x1b[0m',       # misc
+                     '':               '',
+                     None:             ''}
 
     def __init__(self, stream=None):
         super().__init__(stream)
