@@ -1,19 +1,29 @@
 
-""" determine which site-packages and python interpreter version are installed """
-
+import os
 import sys
 from collections import OrderedDict
 
-""" ordereddict:
+python_version      = sys.version_info
+is_pypy_interpreter = ('__pypy__' in sys.builtin_module_names)
+is_windows_os       = (os.name == 'nt')
+is_tty_console      = (hasattr(sys.stdout, 'isatty') and sys.stdout.isatty())
+is_utf_console      = ('utf' in sys.stdout.encoding.lower())
+
+''' ordereddict:
     starting at python 3.6 the built-in dict is both 
     insertion-ordered AND compact, using about half the 
     memory of collections.OrderedDict
-"""
-if sys.version_info >= (3, 6):
+'''
+if python_version >= (3, 6):
     ordereddict = dict
 else:
     ordereddict = OrderedDict
 
+try:
+    import _pickle as cpickle
+except ImportError:
+    import pickle as cpickle
+
 try:
     import dateutil
     dateutil_installed = True
@@ -38,8 +48,14 @@ try:
 except ImportError:
     line_profiler_installed = False
 
-
+# is_pypy_interpreter = True
+# is_windows_os       = True
 # dateutil_installed      = False
 # ultrajson_installed     = False
 # line_profiler_installed = False
 
+# determines if excel_com module should be loaded in __init__
+loads_excel_module = (not is_pypy_interpreter) and is_windows_os
+pass
+
+
