@@ -10,6 +10,8 @@ from .excel_address import col_letter_offset
 from .excel_address import col_letter
 from .excel_address import col_number
 
+from .classes import excel_levity_cls
+
 __all__ = ['open_workbook',
            'close_workbook',
            'new_excel_application',
@@ -18,4 +20,5 @@ __all__ = ['open_workbook',
            'all_excel_instances',
            'col_letter_offset',
            'col_letter',
-           'col_number']
+           'col_number',
+           'excel_levity_cls']
