@@ -8,12 +8,14 @@ from .filesystem import write_file
 from .iter import OrderedDefaultDict
 from .iter import transpose
 
-from .text import print_performance
 from .text import print_runtime
+from .text import print_performance
+from .text import styled
 
 
 __all__ = ['print_runtime',
            'print_performance',
+           'styled',
            'to_datetime',
            'is_date',
            'read_file',
